Struct aws_sdk_appsync::client::fluent_builders::CreateFunction [−][src]
pub struct CreateFunction<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to CreateFunction.
Creates a Function object.
A function is a reusable entity. Multiple functions can be used to compose the resolver logic.
Implementations
impl<C, M, R> CreateFunction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> CreateFunction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<CreateFunctionOutput, SdkError<CreateFunctionError>> where
R::Policy: SmithyRetryPolicy<CreateFunctionInputOperationOutputAlias, CreateFunctionOutput, CreateFunctionError, CreateFunctionInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<CreateFunctionOutput, SdkError<CreateFunctionError>> where
R::Policy: SmithyRetryPolicy<CreateFunctionInputOperationOutputAlias, CreateFunctionOutput, CreateFunctionError, CreateFunctionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The GraphQL API ID.
The Function name. The function name does not have to be unique.
The Function name. The function name does not have to be unique.
The Function description.
The Function description.
The Function
DataSource name.
The Function
DataSource name.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function response mapping template.
The Function response mapping template.
The version of the request mapping template. Currently the supported value
is 2018-05-29.
The version of the request mapping template. Currently the supported value
is 2018-05-29.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.