Struct aws_sdk_appsync::client::fluent_builders::GetFunction [−][src]
pub struct GetFunction<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetFunction.
Get a Function.
Implementations
impl<C, M, R> GetFunction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetFunction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<GetFunctionOutput, SdkError<GetFunctionError>> where
R::Policy: SmithyRetryPolicy<GetFunctionInputOperationOutputAlias, GetFunctionOutput, GetFunctionError, GetFunctionInputOperationRetryAlias>,
pub async fn send(self) -> Result<GetFunctionOutput, SdkError<GetFunctionError>> where
R::Policy: SmithyRetryPolicy<GetFunctionInputOperationOutputAlias, GetFunctionOutput, GetFunctionError, GetFunctionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The GraphQL API ID.
The Function ID.
The Function ID.