Struct aws_sdk_appsync::client::fluent_builders::UpdateFunction [−][src]
pub struct UpdateFunction<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateFunction.
Updates a Function object.
Implementations
impl<C, M, R> UpdateFunction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateFunction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateFunctionOutput, SdkError<UpdateFunctionError>> where
R::Policy: SmithyRetryPolicy<UpdateFunctionInputOperationOutputAlias, UpdateFunctionOutput, UpdateFunctionError, UpdateFunctionInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateFunctionOutput, SdkError<UpdateFunctionError>> where
R::Policy: SmithyRetryPolicy<UpdateFunctionInputOperationOutputAlias, UpdateFunctionOutput, UpdateFunctionError, UpdateFunctionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The GraphQL API ID.
The Function description.
The Function description.
The function ID.
The function ID.
The Function
DataSource name.
The Function
DataSource name.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function request mapping template.
The Function request mapping template.
The version of the request mapping template. Currently the supported value
is 2018-05-29.
The version of the request mapping template. Currently the supported value
is 2018-05-29.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.