Enum aws_sdk_appsync::error::CreateGraphqlApiErrorKind [−][src]
#[non_exhaustive]
pub enum CreateGraphqlApiErrorKind {
ApiLimitExceededException(ApiLimitExceededException),
BadRequestException(BadRequestException),
ConcurrentModificationException(ConcurrentModificationException),
InternalFailureException(InternalFailureException),
LimitExceededException(LimitExceededException),
UnauthorizedException(UnauthorizedException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreateGraphqlApi operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApiLimitExceededException(ApiLimitExceededException)The GraphQL API exceeded a limit. Try your request again.
Tuple Fields of ApiLimitExceededException
BadRequestException(BadRequestException)The request is not well formed. For example, a value is invalid or a required field is missing. Check the field values, and then try again.
Tuple Fields of BadRequestException
ConcurrentModificationException(ConcurrentModificationException)Another modification is in progress at this time and it must complete before you can make your change.
Tuple Fields of ConcurrentModificationException
InternalFailureException(InternalFailureException)An internal AppSync error occurred. Try your request again.
Tuple Fields of InternalFailureException
LimitExceededException(LimitExceededException)The request exceeded a limit. Try your request again.
Tuple Fields of LimitExceededException
You are not authorized to perform this operation.
Tuple Fields of UnauthorizedException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code