Enum aws_sdk_appsync::error::GetIntrospectionSchemaErrorKind [−][src]
#[non_exhaustive]
pub enum GetIntrospectionSchemaErrorKind {
GraphQlSchemaException(GraphQlSchemaException),
InternalFailureException(InternalFailureException),
NotFoundException(NotFoundException),
UnauthorizedException(UnauthorizedException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetIntrospectionSchema operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GraphQlSchemaException(GraphQlSchemaException)The GraphQL schema is not valid.
Tuple Fields of GraphQlSchemaException
InternalFailureException(InternalFailureException)An internal AppSync error occurred. Try your request again.
Tuple Fields of InternalFailureException
NotFoundException(NotFoundException)The resource specified in the request was not found. Check the resource, and then try again.
Tuple Fields of NotFoundException
You are not authorized to perform this operation.
Tuple Fields of UnauthorizedException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code