Enum aws_sdk_appsync::error::ListDataSourcesErrorKind [−][src]
#[non_exhaustive]
pub enum ListDataSourcesErrorKind {
BadRequestException(BadRequestException),
InternalFailureException(InternalFailureException),
NotFoundException(NotFoundException),
UnauthorizedException(UnauthorizedException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the ListDataSources operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadRequestException(BadRequestException)The request is not well formed. For example, a value is invalid or a required field is missing. Check the field values, and then try again.
Tuple Fields of BadRequestException
InternalFailureException(InternalFailureException)An internal AppSync error occurred. Try your request again.
Tuple Fields of InternalFailureException
NotFoundException(NotFoundException)The resource specified in the request was not found. Check the resource, and then try again.
Tuple Fields of NotFoundException
You are not authorized to perform this operation.
Tuple Fields of UnauthorizedException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code