Enum aws_sdk_appsync::error::UpdateApiKeyErrorKind [−][src]
#[non_exhaustive]
pub enum UpdateApiKeyErrorKind {
ApiKeyValidityOutOfBoundsException(ApiKeyValidityOutOfBoundsException),
BadRequestException(BadRequestException),
InternalFailureException(InternalFailureException),
LimitExceededException(LimitExceededException),
NotFoundException(NotFoundException),
UnauthorizedException(UnauthorizedException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdateApiKey operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApiKeyValidityOutOfBoundsException(ApiKeyValidityOutOfBoundsException)The API key expiration must be set to a value between 1 and 365 days from creation (for
CreateApiKey) or from update (for UpdateApiKey).
Tuple Fields of ApiKeyValidityOutOfBoundsException
BadRequestException(BadRequestException)The request is not well formed. For example, a value is invalid or a required field is missing. Check the field values, and then try again.
Tuple Fields of BadRequestException
InternalFailureException(InternalFailureException)An internal AppSync error occurred. Try your request again.
Tuple Fields of InternalFailureException
LimitExceededException(LimitExceededException)The request exceeded a limit. Try your request again.
Tuple Fields of LimitExceededException
NotFoundException(NotFoundException)The resource specified in the request was not found. Check the resource, and then try again.
Tuple Fields of NotFoundException
You are not authorized to perform this operation.
Tuple Fields of UnauthorizedException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code