Struct aws_sdk_appsync::input::create_function_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateFunctionInput
Implementations
The GraphQL API ID.
The Function name. The function name does not have to be unique.
The Function name. The function name does not have to be unique.
The Function description.
The Function description.
The Function
DataSource name.
The Function
DataSource name.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function response mapping template.
The Function response mapping template.
The version of the request mapping template. Currently the supported value
is 2018-05-29.
The version of the request mapping template. Currently the supported value
is 2018-05-29.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Consumes the builder and constructs a CreateFunctionInput