Struct aws_sdk_appsync::input::list_api_keys_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListApiKeysInput
Implementations
The API ID.
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
The maximum number of results you want the request to return.
The maximum number of results you want the request to return.
Consumes the builder and constructs a ListApiKeysInput