Struct aws_sdk_appsync::input::UpdateFunctionInput [−][src]
#[non_exhaustive]pub struct UpdateFunctionInput {
pub api_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub function_id: Option<String>,
pub data_source_name: Option<String>,
pub request_mapping_template: Option<String>,
pub response_mapping_template: Option<String>,
pub function_version: Option<String>,
pub sync_config: Option<SyncConfig>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.api_id: Option<String>The GraphQL API ID.
name: Option<String>The Function name.
description: Option<String>The Function description.
function_id: Option<String>The function ID.
data_source_name: Option<String>The Function
DataSource name.
request_mapping_template: Option<String>The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
response_mapping_template: Option<String>The Function request mapping template.
function_version: Option<String>The version of the request mapping template. Currently the supported value
is 2018-05-29.
sync_config: Option<SyncConfig>Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateFunction, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateFunction, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateFunction>
Creates a new builder-style object to manufacture UpdateFunctionInput