Struct aws_sdk_appsync::model::function_configuration::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for FunctionConfiguration
Implementations
A unique ID representing the Function object.
A unique ID representing the Function object.
The ARN of the Function object.
The ARN of the Function object.
The Function description.
The Function description.
The name of the DataSource.
The name of the DataSource.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function request mapping template. Functions support only the
2018-05-29 version of the request mapping template.
The Function response mapping template.
The Function response mapping template.
The version of the request mapping template. Currently only the 2018-05-29 version of the template is supported.
The version of the request mapping template. Currently only the 2018-05-29 version of the template is supported.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Consumes the builder and constructs a FunctionConfiguration