Struct aws_sdk_appsync::model::CachingConfig [−][src]
The caching configuration for a resolver that has caching enabled.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ttl: i64The TTL in seconds for a resolver that has caching enabled.
Valid values are between 1 and 3600 seconds.
caching_keys: Option<Vec<String>>The caching keys for a resolver that has caching enabled.
Valid values are entries from the $context.arguments,
$context.source, and $context.identity maps.
Implementations
Creates a new builder-style object to manufacture CachingConfig