Struct aws_sdk_appsync::model::DeltaSyncConfig [−][src]
#[non_exhaustive]pub struct DeltaSyncConfig {
pub base_table_ttl: i64,
pub delta_sync_table_name: Option<String>,
pub delta_sync_table_ttl: i64,
}Expand description
Describes a Delta Sync configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.base_table_ttl: i64The number of minutes an Item is stored in the datasource.
delta_sync_table_name: Option<String>The Delta Sync table name.
delta_sync_table_ttl: i64The number of minutes a Delta Sync log entry is stored in the Delta Sync table.
Implementations
Creates a new builder-style object to manufacture DeltaSyncConfig