Struct aws_sdk_appsync::model::OpenIdConnectConfig [−][src]
#[non_exhaustive]pub struct OpenIdConnectConfig {
pub issuer: Option<String>,
pub client_id: Option<String>,
pub iat_ttl: i64,
pub auth_ttl: i64,
}Expand description
Describes an OpenID Connect configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.issuer: Option<String>The issuer for the OpenID Connect configuration. The issuer returned by discovery must
exactly match the value of iss in the ID token.
client_id: Option<String>The client identifier of the Relying party at the OpenID identity provider. This identifier is typically obtained when the Relying party is registered with the OpenID identity provider. You can specify a regular expression so the AppSync can validate against multiple client identifiers at a time.
iat_ttl: i64The number of milliseconds a token is valid after being issued to a user.
auth_ttl: i64The number of milliseconds a token is valid after being authenticated.
Implementations
Creates a new builder-style object to manufacture OpenIdConnectConfig