Struct aws_sdk_appsync::model::SyncConfig [−][src]
#[non_exhaustive]pub struct SyncConfig {
pub conflict_handler: Option<ConflictHandlerType>,
pub conflict_detection: Option<ConflictDetectionType>,
pub lambda_conflict_handler_config: Option<LambdaConflictHandlerConfig>,
}Expand description
Describes a Sync configuration for a resolver.
Contains information on which Conflict Detection as well as Resolution strategy should be performed when the resolver is invoked.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.conflict_handler: Option<ConflictHandlerType>The Conflict Resolution strategy to perform in the event of a conflict.
-
OPTIMISTIC_CONCURRENCY: Resolve conflicts by rejecting mutations when versions do not match the latest version at the server.
-
AUTOMERGE: Resolve conflicts with the Automerge conflict resolution strategy.
-
LAMBDA: Resolve conflicts with a Lambda function supplied in the LambdaConflictHandlerConfig.
conflict_detection: Option<ConflictDetectionType>The Conflict Detection strategy to use.
-
VERSION: Detect conflicts based on object versions for this resolver.
-
NONE: Do not detect conflicts when executing this resolver.
lambda_conflict_handler_config: Option<LambdaConflictHandlerConfig>The LambdaConflictHandlerConfig when configuring LAMBDA as the Conflict
Handler.
Implementations
Creates a new builder-style object to manufacture SyncConfig