Struct aws_sdk_appsync::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for AWSDeepdishControlPlaneService.
This client allows ergonomic access to a AWSDeepdishControlPlaneService-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the CreateApiCache operation.
See CreateApiCache for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateApiKey operation.
See CreateApiKey for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateDataSource operation.
See CreateDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateFunction operation.
See CreateFunction for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateGraphqlApi operation.
See CreateGraphqlApi for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateResolver operation.
See CreateResolver for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateType operation.
See CreateType for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteApiCache operation.
See DeleteApiCache for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteApiKey operation.
See DeleteApiKey for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteDataSource operation.
See DeleteDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteFunction operation.
See DeleteFunction for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteGraphqlApi operation.
See DeleteGraphqlApi for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteResolver operation.
See DeleteResolver for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteType operation.
See DeleteType for more information about the
operation and its arguments.
Constructs a fluent builder for the FlushApiCache operation.
See FlushApiCache for more information about the
operation and its arguments.
Constructs a fluent builder for the GetApiCache operation.
See GetApiCache for more information about the
operation and its arguments.
Constructs a fluent builder for the GetDataSource operation.
See GetDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the GetFunction operation.
See GetFunction for more information about the
operation and its arguments.
Constructs a fluent builder for the GetGraphqlApi operation.
See GetGraphqlApi for more information about the
operation and its arguments.
Constructs a fluent builder for the GetIntrospectionSchema operation.
See GetIntrospectionSchema for more information about the
operation and its arguments.
Constructs a fluent builder for the GetResolver operation.
See GetResolver for more information about the
operation and its arguments.
Constructs a fluent builder for the GetSchemaCreationStatus operation.
See GetSchemaCreationStatus for more information about the
operation and its arguments.
Constructs a fluent builder for the GetType operation.
See GetType for more information about the
operation and its arguments.
Constructs a fluent builder for the ListApiKeys operation.
See ListApiKeys for more information about the
operation and its arguments.
Constructs a fluent builder for the ListDataSources operation.
See ListDataSources for more information about the
operation and its arguments.
Constructs a fluent builder for the ListFunctions operation.
See ListFunctions for more information about the
operation and its arguments.
Constructs a fluent builder for the ListGraphqlApis operation.
See ListGraphqlApis for more information about the
operation and its arguments.
Constructs a fluent builder for the ListResolvers operation.
See ListResolvers for more information about the
operation and its arguments.
Constructs a fluent builder for the ListResolversByFunction operation.
See ListResolversByFunction for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTypes operation.
See ListTypes for more information about the
operation and its arguments.
Constructs a fluent builder for the StartSchemaCreation operation.
See StartSchemaCreation for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateApiCache operation.
See UpdateApiCache for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateApiKey operation.
See UpdateApiKey for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateDataSource operation.
See UpdateDataSource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateFunction operation.
See UpdateFunction for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateGraphqlApi operation.
See UpdateGraphqlApi for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateResolver operation.
See UpdateResolver for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateType operation.
See UpdateType for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.